..
    Copyright (C) 2023 Graz University of Technology.

    invenio-records-global-search is free software; you can redistribute it
    and/or modify it under the terms of the MIT License; see LICENSE file for
    more details.

Authors
=======

Dublin Core data model for InvenioRDM

- TU Graz <christoph.ladurner@tugraz.at>
